@@ -1,5 +1,5 @@
-#ifndef GNOME_PROFILE_H
-#define GNOME_PROFILE_H
+#ifndef GNOME_CONFIG_H
+#define GNOME_CONFIG_H
 
 /* Prototypes for the profile management functions */
 
