@@ -7,6 +7,7 @@
 #include <glib.h>
 #include "gnome-defs.h"
 #include "gnome-util.h"
+#include "libintl.h"
 
 char *gnome_user_home_dir = 0;
 char *gnome_user_dir = 0;
@@ -17,6 +18,10 @@ gnomelib_init (int *argc, char ***argv)
 	gnome_user_home_dir = getenv ("HOME");
 	gnome_user_dir = g_concat_dir_and_file (gnome_user_home_dir, ".gnome");
 	mkdir (gnome_user_dir, 0777);
+
+	setlocale (LC_ALL, "");
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	textdomain (PACKAGE);
 }
 
 
