@@ -71,8 +71,6 @@ main (int argc, char *argv [])
 	gtk_init (&argc, &argv);
 	gnome_init (&argc, &argv);
 	
-	gtk_widget_set_default_visual(gtk_preview_get_visual());
-	gtk_widget_set_default_colormap(gtk_preview_get_cmap());
 	display_properties_setup ();
 	configurators_setup ();
 #if 0
