@@ -1,10 +1,14 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <gtk/gtk.h>
+#include <libintl.h>
+
 #include "gnome.h"
 #include "gnome-desktop.h"
 #include "gtkpreviewextra.h"
 
+#define _(String) gettext(String)
+
 #define PAD 10
 
 static GtkWidget *frame;
@@ -192,7 +196,7 @@ color_setup ()
 	GtkWidget *radio2;
 	GdkColor  color1, color2;
 	
-	frame = gtk_frame_new("Color");
+	frame = gtk_frame_new(_("Color"));
 	gtk_widget_show(frame);
 
 	table = gtk_table_new(4, 2, FALSE);
@@ -210,7 +214,7 @@ color_setup ()
 	gtk_table_attach(GTK_TABLE(table), button1, 0, 1, 0, 2, 0, 0, 0, 0);
 	gtk_widget_show(button1);
 
-	radio1 = gtk_radio_button_new_with_label(NULL, "Flat");
+	radio1 = gtk_radio_button_new_with_label(NULL, _("Flat"));
 	gtk_signal_connect (GTK_OBJECT(radio1), "toggled",
 			    (GtkSignalFunc) set_background_mode,
 			    (gpointer) ((long) FALSE));
@@ -218,7 +222,7 @@ color_setup ()
 	gtk_widget_show(radio1);
 
 	radio1 = gtk_radio_button_new_with_label(gtk_radio_button_group(GTK_RADIO_BUTTON(radio1)),
-						 "Gradient");
+						 _("Gradient"));
 	gtk_signal_connect (GTK_OBJECT(radio1), "toggled",
 			    (GtkSignalFunc) set_background_mode,
 			    (gpointer) ((long) TRUE));
@@ -239,7 +243,7 @@ color_setup ()
 			   (GtkSignalFunc) radio_toggle_widget_active,
 			   button2);
 
-	radio2 = gtk_radio_button_new_with_label(NULL, "Vertical");
+	radio2 = gtk_radio_button_new_with_label(NULL, _("Vertical"));
 	gtk_signal_connect(GTK_OBJECT(radio2), "toggled",
 			   (GtkSignalFunc) set_orientation,
 			   (gpointer) ((long) TRUE));
@@ -251,7 +255,7 @@ color_setup ()
 			   radio2);
 
 	radio2 = gtk_radio_button_new_with_label(gtk_radio_button_group(GTK_RADIO_BUTTON(radio2)),
-						 "Horizontal");
+						 _("Horizontal"));
 	gtk_signal_connect(GTK_OBJECT(radio2), "toggled",
 			   (GtkSignalFunc) set_orientation,
 			   (gpointer) ((long) FALSE));
@@ -270,7 +274,7 @@ wallpaper_setup ()
 {
 	GtkWidget *wallp;
 
-	wallp = gtk_frame_new ("Wallpaper");
+	wallp = gtk_frame_new (_("Wallpaper"));
 	gtk_widget_show (wallp);
 	return wallp;
 }
@@ -330,5 +334,5 @@ background_setup (GtkWidget *window)
 	gtk_box_pack_end (GTK_BOX (settings), wallp, 1, 1, PAD);
 	
 	gtk_widget_show (vbox);
-        register_extension (gtk_label_new ("Background"), vbox, background_action);
+        register_extension (gtk_label_new (_("Background")), vbox, background_action);
 }
